aboutsummaryrefslogtreecommitdiffstats
path: root/mkclrnam.scm
diff options
context:
space:
mode:
Diffstat (limited to 'mkclrnam.scm')
-rw-r--r--mkclrnam.scm22
1 files changed, 13 insertions, 9 deletions
diff --git a/mkclrnam.scm b/mkclrnam.scm
index 7377f37..3e0c553 100644
--- a/mkclrnam.scm
+++ b/mkclrnam.scm
@@ -198,7 +198,7 @@
(define *rcs-header* (read-line port))
(do ((line (read-line port) (read-line port)))
((eof-object? line)
- (display "Inserted ") (display *idx*) (display "colors") (newline)
+ (display "Inserted ") (display *idx*) (display " colors") (newline)
*rcs-header*)
(let ((colin (parse-rgb-line line)))
(cond ((equal? "" line))
@@ -222,7 +222,7 @@
;;This section has detailed the procedures for creating and loading
;;color dictionaries. So where are the dictionaries to load?
;;
-;;@uref{http://swissnet.ai.mit.edu/~jaffer/Color/Dictionaries.html}
+;;@uref{http://swiss.csail.mit.edu/~jaffer/Color/Dictionaries.html}
;;
;;@noindent
;;Describes and evaluates several color-name dictionaries on the web.
@@ -234,13 +234,14 @@
;;containing the @dfn{Resene} and @dfn{saturate} color-name
;;dictionaries.
;;
;;If the files @file{resenecolours.txt} and @file{saturate.txt} exist in
;;the @r{library-vicinity}, then they used as the source of color-name
;;data. Otherwise, @0 calls url->color-dictionary with the URLs of
;;appropriate source files.
(define (make-slib-color-name-db)
(define cndb (create-database (in-vicinity (library-vicinity) "clrnamdb.scm")
'alist-table))
+ (or cndb (slib:error 'cannot 'create 'database "clrnamdb.scm"))
(for-each
(lambda (lst)
(apply
@@ -250,10 +251,13 @@
(file->color-dictionary filename name cndb)
(url->color-dictionary url name cndb)))
lst))
- '(("http://swissnet.ai.mit.edu/~jaffer/Color/saturate.txt"
+ '(("http://swiss.csail.mit.edu/~jaffer/Color/saturate.txt"
"saturate.txt"
saturate)
- ("http://swissnet.ai.mit.edu/~jaffer/Color/resenecolours.txt"
+ ("http://swiss.csail.mit.edu/~jaffer/Color/resenecolours.txt"
"resenecolours.txt"
- resene)))
+ resene)
+ ("http://swiss.csail.mit.edu/~jaffer/Color/nbs-iscc.txt"
+ "nbs-iscc.txt"
+ nbs-iscc)))
(close-database cndb))
@@ -234,13 +234,14 @@
;;dictionaries.
;;
-;;If the files @file{resenecolours.txt} and @file{saturate.txt} exist in
-;;the @r{library-vicinity}, then they used as the source of color-name
-;;data. Otherwise, @0 calls url->color-dictionary with the URLs of
-;;appropriate source files.
+;;If the files @file{resenecolours.txt}, @file{nbs-iscc.txt}, and
+;;@file{saturate.txt} exist in the @r{library-vicinity}, then they
+;;used as the source of color-name data. Otherwise, @0 calls
+;;url->color-dictionary with the URLs of appropriate source files.
(define (make-slib-color-name-db)
(define cndb (create-database (in-vicinity (library-vicinity) "clrnamdb.scm")